from inkbox.mail.resources.mailboxes import MailboxesResource
from inkbox.mail.resources.messages import MessagesResource
from inkbox.mail.resources.threads import ThreadsResource

__all__ = [
    "MailboxesResource",
    "MessagesResource",
    "ThreadsResource",
]
